@@ -1,6 +1,6 @@
 """A friendly Python Utilitary RPA."""
 
-__version__ = "1.17"
+__version__ = "1.18"
 __author__ = "Jonathan Bolo"
 
 import os, re, shutil
@@ -1128,4 +1128,17 @@ def lista_feriados(anio):
         feriados_desafectados = np.fromiter((element for element in lista_feriados if element <= 60), dtype = lista_feriados.dtype)
         lista_feriados = np.concatenate((feriados_desafectados,feriados_afectados),axis=0)
     
-    return list(lista_feriados)
\ No newline at end of file
+    return list(lista_feriados)
+
+def notifica_exception(exception=None, notifica=None, lista_exceptions_bl=[], subject_replace=None, body_replace=None):
+    """Función que notifica todas las excepciones. Si alguna se encuentra en la lista blacklist, no se notifica"""
+    if not subject_replace:
+        subject_replace = "Error"
+    if not body_replace:
+        body_replace = "IDS000-Ocurrio un error generico en el proceso: "
+    
+    if str(type(exception).__name__).startswith("ID"):
+        if type(exception).__name__ not in lista_exceptions_bl:
+            notifica.enviar_correo({'[TEXTO]':subject_replace}, {'[TEXTO]':str(exception)})
+    else:
+        notifica.enviar_correo({'[TEXTO]':subject_replace}, {'[TEXTO]':body_replace + str(exception)})
\ No newline at end of file
